@@ -26,6 +26,7 @@ from .api_client import ApiClient
 from .configuration import Configuration
 # import client apis into kfserving package
 from .api.kf_serving_client import KFServingClient
+from .constants import constants
 
 # import models into kfserving package
 from .models.knative_addressable import KnativeAddressable
@@ -34,6 +35,7 @@ from .models.knative_url import KnativeURL
 from .models.knative_volatile_time import KnativeVolatileTime
 from .models.net_url_userinfo import NetUrlUserinfo
 from .models.v1alpha2_alibi_explainer_spec import V1alpha2AlibiExplainerSpec
+from .models.v1alpha2_batcher import V1alpha2Batcher
 from .models.v1alpha2_custom_spec import V1alpha2CustomSpec
 from .models.v1alpha2_inference_service import V1alpha2InferenceService
 from .models.v1alpha2_inference_service_list import V1alpha2InferenceServiceList
@@ -48,6 +50,6 @@ from .models.v1alpha2_sk_learn_spec import V1alpha2SKLearnSpec
 from .models.v1alpha2_logger import V1alpha2Logger
 from .models.v1alpha2_onnx_spec import V1alpha2ONNXSpec
 from .models.v1alpha2_status_configuration_spec import V1alpha2StatusConfigurationSpec
-from .models.v1alpha2_tensor_rt_spec import V1alpha2TensorRTSpec
+from .models.v1alpha2_triton_spec import V1alpha2TritonSpec
 from .models.v1alpha2_tensorflow_spec import V1alpha2TensorflowSpec
 from .models.v1alpha2_xg_boost_spec import V1alpha2XGBoostSpec
