@@ -43,6 +43,7 @@ class KFServingClient(object):
         else:
             config.load_incluster_config()
         self.core_api = client.CoreV1Api()
+        self.app_api = client.AppsV1Api()
         self.api_instance = client.CustomObjectsApi()
 
     def set_credentials(self, storage_type, namespace=None, credentials_file=None,
@@ -289,12 +290,18 @@ class KFServingClient(object):
         except KeyError:
             raise RuntimeError("Cannot promote a InferenceService that has no Canary Spec.")
 
+        try:
+            annotations = current_isvc['metadata']['annotations']
+        except KeyError:
+            annotations = dict()
+
         inferenceservice = V1alpha2InferenceService(
             api_version=api_version,
             kind=constants.KFSERVING_KIND,
             metadata=client.V1ObjectMeta(
                 name=name,
-                namespace=namespace),
+                namespace=namespace,
+                annotations=annotations),
             spec=V1alpha2InferenceServiceSpec(
                 default=current_canary_spec,
                 canary=None,
